==> haskell-rvar-0.2.0.6-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rvar
version:              0.2.0.6
visibility:           public
id:                   rvar-0.2.0.6-JLpWlGLiqvwLXwp3aoP7nz
key:                  rvar-0.2.0.6-JLpWlGLiqvwLXwp3aoP7nz
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

    Changes in 0.2.0.1:  Version bump for transformers
    dependency.

category:             Math
abi:                  6a49b19a016a092e06524420d7884729
exposed:              True
exposed-modules:      Data.RVar
import-dirs:          /usr/lib/ghc-8.10.4/site-local/rvar-0.2.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/rvar-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/rvar-0.2.0.6
hs-libraries:         HSrvar-0.2.0.6-JLpWlGLiqvwLXwp3aoP7nz
depends:
    MonadPrompt-1.0.0.5-GcXKT497G1U1Gu0Zf8sWqX base-4.14.1.0 mtl-2.2.2
    random-source-0.3.0.11-12aaiVXvr4n7KJdHKiTzKD transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rvar-0.2.0.6-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rvar
version:              0.2.0.6
visibility:           public
id:                   rvar-0.2.0.6-CCvyJgAJBi97XJ6oBCTC7l
key:                  rvar-0.2.0.6-CCvyJgAJBi97XJ6oBCTC7l
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

    Changes in 0.2.0.1:  Version bump for transformers
    dependency.

category:             Math
abi:                  a0847dd5451968395cdfc0dac42c66b9
exposed:              True
exposed-modules:      Data.RVar
import-dirs:          /usr/lib/ghc-8.10.4/site-local/rvar-0.2.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/rvar-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/rvar-0.2.0.6
hs-libraries:         HSrvar-0.2.0.6-CCvyJgAJBi97XJ6oBCTC7l
depends:
    MonadPrompt-1.0.0.5-GcXKT497G1U1Gu0Zf8sWqX base-4.14.1.0 mtl-2.2.2
    random-source-0.3.0.11-2bDVErTHn1x34VEFH6bwGH transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
